==> xpilot_4.1.0.orig.tar.gz: xpilot-4.1.0/src/mapedit/defaults.h <==
/*
 * XMapEdit, the XPilot Map Editor.  Copyright (C) 1993 by
 *
 *      Aaron Averill           <averila@oes.orst.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Modifications to XMapEdit
 * 1996:
 *      Robert Templeman        <mbcaprt@mphhpd.ph.man.ac.uk>
 * 1997:
 *      William Docter          <wad2@lehigh.edu>
 *
 * $Id: defaults.h,v 1.4 1998/04/22 17:23:32 bert Exp $
 */

/* defaults
 * v3.5.1
 * Last updated, Jul 4, 1996
 *
 * created July 10, 1993
 */

#define MAX_MAP_SIZE          900
#define DEFAULT_WIDTH         200
#define DEFAULT_HEIGHT        200
#define DEFAULT_MAP_ZOOM      20

#define DRAW_ICON_BTN         Button1
#define LINE_ICON_BTN         Button1
#define SELECT_BTN            Button2

#define PREF_X                -1
#define PREF_Y                -1
#define PREF_WIDTH            1024
#define PREF_HEIGHT           860
#define PREF_BTN_WIDTH        60
#define PREF_BTN_HEIGHT       18

#define HELP_X                -1
#define HELP_Y                -1
#define HELP_WIDTH            500
#define HELP_HEIGHT           600
#define HELP_BTN_WIDTH        50
#define HELP_BTN_HEIGHT       27
 
#define TOOLSWIDTH            200
#define TOOLSHEIGHT           720

==> xpilot-4.3.1.tar.gz: xpilot-4.3.1/src/mapedit/defaults.h <==
/*
 * XMapEdit, the XPilot Map Editor.  Copyright (C) 1993 by
 *
 *      Aaron Averill           <averila@oes.orst.edu>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Modifications to XMapEdit
 * 1996:
 *      Robert Templeman        <mbcaprt@mphhpd.ph.man.ac.uk>
 * 1997:
 *      William Docter          <wad2@lehigh.edu>
 *
 * $Id: defaults.h,v 1.5 2000/03/11 20:25:58 bert Exp $
 */

/* defaults
 * v3.5.1
 * Last updated, Jul 4, 1996
 *
 * created July 10, 1993
 */

#define MAX_MAP_SIZE          900
#define DEFAULT_WIDTH         200
#define DEFAULT_HEIGHT        200
#define DEFAULT_MAP_ZOOM      20

#define DRAW_ICON_BTN         Button1
#define LINE_ICON_BTN         Button1
#define SELECT_BTN            Button2

#define PREF_X                -1
#define PREF_Y                -1
#define PREF_WIDTH            1500 /*1024*/
#define PREF_HEIGHT           860
#define PREF_BTN_WIDTH        60
#define PREF_BTN_HEIGHT       18

#define HELP_X                -1
#define HELP_Y                -1
#define HELP_WIDTH            500
#define HELP_HEIGHT           600
#define HELP_BTN_WIDTH        50
#define HELP_BTN_HEIGHT       27
 
#define TOOLSWIDTH            200
#define TOOLSHEIGHT           720
